| epiworld-hospitalizations | R Documentation |
Weighted hospitalization tracking when agents have multiple tools.
get_hospitalizations(x)
x |
An object of class |
The function get_hospitalizations returns a data.frame with five columns:
date, virus_id, tool_id, hospitalizations, and weight. The weight
column is used to keep track of individuals having multiple tools. For
example, if an agent has two tools (vaccination and mask-wearing), then it
will show up twice under count, but with weights 0.5 for each count. Models
with no hospitalization tracking will return the same data.frame with no
rows.
Other Summaries:
epiworld-summaries
# See model documentation for examples with hospitalization tracking
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.