Learn R Programming

epiworldR (version 0.11.2.0)

epiworld-hospitalizations: Hospitalizations by tool

Description

Weighted hospitalization tracking when agents have multiple tools.

Usage

get_hospitalizations(x)

Value

  • The function get_hospitalizations returns a data.frame with five columns: date, virus_id, tool_id, hospitalizations, and weight. The weight column is used to keep track of individuals having multiple tools. For example, if an agent has two tools (vaccination and mask-wearing), then it will show up twice under count, but with weights 0.5 for each count. Models with no hospitalization tracking will return the same data.frame with no rows.

Arguments

x

An object of class epiworld_sir, epiworld_seir, etc. (any model).

See Also

Other Summaries: epiworld-summaries

Examples

Run this code
# See model documentation for examples with hospitalization tracking

Run the code above in your browser using DataLab